@@ -2,7 +2,6 @@ from prompy.ProMExecutor import ProMExecutor
 
 from pathlib import Path
 import zipfile
-from tqdm import tqdm
 import os
 import re
 
@@ -48,7 +47,9 @@ class DocumentationReader:
     functions = prom_executor.get_available_functions()
 
     for function in functions:
-      function = function[:-1]
+      if '->' not in function:
+        continue
+      function = function.rstrip('\r\n')
       function_name, argument_classes, return_classes = self.parse_plugin(function)
       self.classes.update(argument_classes)
       self.classes.update(return_classes)
@@ -94,7 +95,7 @@ class DocumentationGenerator:
       return definition_string
 
   def generate(self, classes, functions):
-    header = 'from prom4py.utils import check_arguments'
+    header = 'from prompy.utils import check_arguments'
 
     body = header + '\n\n'
     for class_name in classes:
@@ -102,7 +103,7 @@ class DocumentationGenerator:
         body += f'class {class_name}:\n    def __init__(self, *args): pass\n'
     body += '\n\n'
 
-    for function in tqdm(functions.values()):
+    for function in functions.values():
       body += self.create_function_definition_string(function) + '\n\n'
 
     with open(self.document_file, 'w') as document_file:
